@@ -652,6 +652,7 @@ class InterpretJAAQL:
         new_query = ""
         last_start_match = 0
         last_end_match = 0
+        start_pos = None
 
         for match in re.finditer(match_regex, query):
             start_pos = match.regs[0][0]
@@ -661,7 +662,10 @@ class InterpretJAAQL:
             last_start_match = start_pos
             last_end_match = end_pos
 
-        return new_query + query[last_end_match:]
+        ret = new_query + query[last_end_match:]
+        if start_pos is not None:
+            print(ret)
+        return ret
 
     def pre_prepare_statement(self, query, parameters, match_regex: str = REGEX_query_argument, encryption_key: bytes = None,
                               require_presence: bool = True, for_prepare: bool = False, skipped_singletons: list[str] = None):
