@@ -68,6 +68,8 @@ class JAAQLController(BaseJAAQLController):
             registered = http_inputs.get(KEY__registered, True)
             if KEY__registered in http_inputs:
                 http_inputs.pop(KEY__registered)
+            if registered is None:
+                registered = True
             self.model.create_account_with_potential_password(connection, **http_inputs, registered=registered)
 
         @self.publish_route('/accounts/batch', DOCUMENTATION__create_account_batch)
@@ -99,8 +101,8 @@ class JAAQLController(BaseJAAQLController):
             return self.model.invite(http_inputs, account_id, is_the_anonymous_user)
 
         @self.publish_route('/sign-up', DOCUMENTATION__sign_up)
-        def sign_up(http_inputs: dict):
-            return self.model.sign_up(http_inputs)
+        def sign_up(http_inputs: dict, ip_address: str, response: JAAQLResponse):
+            return self.model.sign_up(http_inputs, ip_address, response)
 
         @self.publish_route('/sign-up-resend', DOCUMENTATION__resend_sign_up)
         def sign_up_resend(http_inputs: dict, account_id: str, username: str):
